//
//  GraphView.h
//  SecondWindow
//
//  Created by Kenneth Hoffmann on Sun Jun 13 2004.
//  Copyright (c) 2004 __MyCompanyName__. All rights reserved.
//

#import <Foundation/Foundation.h>
@class LineSegment;
@class Breakpoint;
@class CoordConverter;
@class SecondModel;

@interface GraphView : NSView {
	IBOutlet id mouseLocationX;
	IBOutlet id mouseLocationY;
	IBOutlet id numBreakpoints;

	IBOutlet id minXValue;
	IBOutlet id maxXValue;
	IBOutlet id minYValue;
	IBOutlet id maxYValue;
	IBOutlet id resolutionLength;
	IBOutlet NSButton * writeToFileButton;
	IBOutlet NSButton * cancelButton;
	
	IBOutlet id minXValueLabel;
	IBOutlet id maxXValueLabel;
	IBOutlet id minYValueLabel;
	IBOutlet id maxYValueLabel;
	IBOutlet id resolutionLengthLabel;
	
	bool exponential;
	bool linear;
	bool logarithmic;
	
	NSMutableArray * segments;
	NSMutableArray * breakpoints;
	NSMutableArray * paths;
	
	float defaultMinY;
	float defaultMaxY;
	float defaultRes;
	
	CoordConverter * conv;
}

-(void)mouseMoved:(NSEvent *)theEvent;
-(IBAction)selectExponential:(id)sender;
-(IBAction)selectLinear:(id)sender;
-(IBAction)selectLogarithmic:(id)sender;
-(IBAction)newGraph:(id)sender;

-(float)findLinearConstant:(NSPoint)endP stP:(NSPoint)poin;
-(float)findExponentialConstant:(NSPoint)endP poin:(NSPoint)poin;
-(float)findExponentialSlope:(NSPoint)endP poin:(NSPoint)poin;
-(float)findLogarithmicConstant:(NSPoint)endP poin:(NSPoint)poin;
-(float)findLogarithmicSlope:(NSPoint)endP poin:(NSPoint)poin;

-(void)updateNextSegment:(int)segmentIndex position:(NSPoint)mouseLoc;
-(void)adjustFirstPoint:(NSPoint)mouseLoc index:(int)indexOfSelectedSegment brIndex:(int)indexOfBreakpoint;
-(void)adjustLastPoint:(NSPoint)mouseLoc index:(int)indexOfSelectedSegment brIndex:(int)indexOfBreakpoint;

-(void)updateLineType:(int)indexOfSelectedSegment;
-(float)findYforX:(float)x indx:(int)index;
-(void)printBreakpoints;
-(void)printLines;

-(float)breakpointDoesOverlap:(int)brIndex loc:(NSPoint)mouseLoc;
-(void)checkIfNegative:(LineSegment *)seg;

-(float)readField:(NSString *)str;
-(IBAction)didFinishMinX:(id)sender;
-(IBAction)didFinishMaxX:(id)sender;
-(IBAction)didFinishMinY:(id)sender;
-(IBAction)didFinishMaxY:(id)sender;
-(IBAction)didFinishResolution:(id)sender;

-(void)setMinY:(float)min;
-(void)setMaxY:(float)max;
-(void)setResolution:(float)res;

-(BOOL)writeToFile:(NSString *)path;

-(NSData *)saveGraph;
-(void)unwrapData:(NSData *)dat;

// Removes all decimals
-(NSString *)roundDouble2:(NSString *)val;

@end
